"use strict";
/**
 * Created by Ivo Meißner on 28.07.17.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
const chai_1 = require("chai");
const schema_1 = __importDefault(require("./fixtures/schema"));
const QueryComplexity_1 = __importStar(require("../QueryComplexity"));
const index_1 = __importStar(require("../index"));
const CompatibleValidationContext_1 = require("./fixtures/CompatibleValidationContext");
describe('QueryComplexity analysis', () => {
    const typeInfo = new graphql_1.TypeInfo(schema_1.default);
    it('exports createComplexityRule as default and named export in index', () => {
        (0, chai_1.expect)(index_1.createComplexityRule).to.equal(index_1.default);
        (0, chai_1.expect)(typeof index_1.createComplexityRule).to.equal('function');
    });
    it('should calculate complexity', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        variableScalar(count: 10)
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 1 })],
            schema: schema_1.default,
            query: ast,
        });
        (0, chai_1.expect)(complexity).to.equal(1);
    });
    it('should respect @include(if: false) via default variable value', () => {
        const ast = (0, graphql_1.parse)(`
      query Foo ($shouldSkip: Boolean = false) {
        variableScalar(count: 10) @include(if: $shouldSkip)
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 1 })],
            schema: schema_1.default,
            query: ast,
        });
        (0, chai_1.expect)(complexity).to.equal(0);
    });
    it('should respect @include(if: false)', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        variableScalar(count: 10) @include(if: false)
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 1 })],
            schema: schema_1.default,
            query: ast,
        });
        (0, chai_1.expect)(complexity).to.equal(0);
    });
    it('should respect @include(if: true)', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        variableScalar(count: 10) @include(if: true)
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 1 })],
            schema: schema_1.default,
            query: ast,
        });
        (0, chai_1.expect)(complexity).to.equal(1);
    });
    it('should respect @skip(if: true)', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        variableScalar(count: 10) @skip(if: true)
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 1 })],
            schema: schema_1.default,
            query: ast,
        });
        (0, chai_1.expect)(complexity).to.equal(0);
    });
    it('should respect @skip(if: false)', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        variableScalar(count: 10) @skip(if: false)
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 1 })],
            schema: schema_1.default,
            query: ast,
        });
        (0, chai_1.expect)(complexity).to.equal(1);
    });
    it('should respect @skip(if: false) @include(if: true)', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        variableScalar(count: 10) @skip(if: false) @include(if: true)
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 1 })],
            schema: schema_1.default,
            query: ast,
        });
        (0, chai_1.expect)(complexity).to.equal(1);
    });
    it('should calculate complexity with variables', () => {
        const ast = (0, graphql_1.parse)(`
      query Q($count: Int) {
        variableScalar(count: $count)
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({ defaultComplexity: 1 }),
            ],
            schema: schema_1.default,
            query: ast,
            variables: {
                count: 5,
            },
        });
        (0, chai_1.expect)(complexity).to.equal(50);
    });
    it('should calculate complexity with variables and default value', () => {
        const ast = (0, graphql_1.parse)(`
      query Q($count: Int = 5) {
        variableScalar(count: $count)
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({ defaultComplexity: 1 }),
            ],
            schema: schema_1.default,
            query: ast,
            variables: {},
        });
        (0, chai_1.expect)(complexity).to.equal(50);
    });
    it('should not allow negative cost', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        variableScalar(count: -100)
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: -100 })],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(0);
    });
    it('should ignore unknown fragments', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        ...UnknownFragment
        variableScalar(count: 100)
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 10 })],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(10);
    });
    it('should ignore inline fragment on unknown type', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        ...on UnknownType {
          variableScalar(count: 100)
        }
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 10 })],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(0);
    });
    it('should ignore fragment on unknown type', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        ...F
      }
      fragment F on UnknownType {
        variableScalar(count: 100)
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 10 })],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(0);
    });
    it('should ignore unused variables', () => {
        const ast = (0, graphql_1.parse)(`
      query ($unusedVar: ID!) {
        variableScalar(count: 100)
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 10 })],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(10);
    });
    it('should ignore unknown field', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        unknownField
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [(0, index_1.simpleEstimator)({ defaultComplexity: 10 })],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(0);
    });
    it('should report error above threshold', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        variableScalar(count: 100)
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({
                    defaultComplexity: 1,
                }),
            ],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(1000);
        (0, chai_1.expect)(context.getErrors().length).to.equal(1);
        (0, chai_1.expect)(context.getErrors()[0].message).to.equal('The query exceeds the maximum complexity of 100. Actual complexity is 1000');
    });
    it('should add inline fragments', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        variableScalar(count: 5)
        ...on Query {
          scalar
          alias: scalar
        }
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({
                    defaultComplexity: 1,
                }),
            ],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(52);
    });
    it('should add fragments', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        scalar
        ...QueryFragment
      }

      fragment QueryFragment on Query {
        variableScalar(count: 2)
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({
                    defaultComplexity: 1,
                }),
            ],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(21);
    });
    it('should add complexity for union types', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        union {
          ...on Item {
            scalar
            complexScalar
          }
        }
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({
                    defaultComplexity: 1,
                }),
            ],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(22);
    });
    it('should add complexity for interface types', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        interface {
          name
          ...on NameInterface {
            name
          }
        }
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({
                    defaultComplexity: 1,
                }),
            ],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(3);
    });
    it('should add complexity for inline fragments without type condition', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        interface {
          ... {
            name
          }
        }
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({
                    defaultComplexity: 1,
                }),
            ],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(2);
    });
    it('should add complexity for enum types', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        enum
      }
    `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({
                    defaultComplexity: 1,
                }),
            ],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(visitor.complexity).to.equal(1);
    });
    it('should report error on a missing non-null argument', () => {
        const ast = (0, graphql_1.parse)(`
        query {
            requiredArgs
        }
      `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({
                    defaultComplexity: 1,
                }),
            ],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(context.getErrors().length).to.equal(1);
        (0, chai_1.expect)(context.getErrors()[0].message).to.equal('Argument "count" of required type "Int!" was not provided.');
    });
    it('should report error when no estimator is configured', () => {
        const ast = (0, graphql_1.parse)(`
        query {
            scalar
        }
      `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(context.getErrors().length).to.equal(1);
        (0, chai_1.expect)(context.getErrors()[0].message).to.equal('No complexity could be calculated for field Query.scalar. ' +
            'At least one complexity estimator has to return a complexity score.');
    });
    it('should report error when no estimator returns value', () => {
        const ast = (0, graphql_1.parse)(`
        query {
            scalar
        }
      `);
        const context = new CompatibleValidationContext_1.CompatibleValidationContext(schema_1.default, ast, typeInfo);
        const visitor = new QueryComplexity_1.default(context, {
            maximumComplexity: 100,
            estimators: [(0, index_1.fieldExtensionsEstimator)()],
        });
        (0, graphql_1.visit)(ast, (0, graphql_1.visitWithTypeInfo)(typeInfo, visitor));
        (0, chai_1.expect)(context.getErrors().length).to.equal(1);
        (0, chai_1.expect)(context.getErrors()[0].message).to.equal('No complexity could be calculated for field Query.scalar. ' +
            'At least one complexity estimator has to return a complexity score.');
    });
    it('should throw error when no astNode available on field when using directiveEstimator', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        _service {
          sdl
        }
      }
    `);
        (0, chai_1.expect)(() => {
            (0, QueryComplexity_1.getComplexity)({
                estimators: [(0, index_1.directiveEstimator)()],
                schema: schema_1.default,
                query: ast,
            });
        }).to.throw(/No complexity could be calculated for field Query._service/);
    });
    it('should skip complexity calculation by directiveEstimator when no astNode available on field', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        _service {
          sdl
        }
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.directiveEstimator)(),
                (0, index_1.simpleEstimator)({
                    defaultComplexity: 1,
                }),
            ],
            schema: schema_1.default,
            query: ast,
        });
        (0, chai_1.expect)(complexity).to.equal(2);
    });
    it('should calculate complexity for specific operation', () => {
        const ast = (0, graphql_1.parse)(`
      query Primary {
        scalar
        complexScalar
      }

      query Secondary {
        complexScalar
      }
    `);
        const complexity1 = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({ defaultComplexity: 1 }),
            ],
            schema: schema_1.default,
            query: ast,
        });
        (0, chai_1.expect)(complexity1).to.equal(41);
        const complexity2 = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({ defaultComplexity: 1 }),
            ],
            schema: schema_1.default,
            query: ast,
            operationName: 'Secondary',
        });
        (0, chai_1.expect)(complexity2).to.equal(20);
    });
    it('should calculate max complexity for fragment on union type', () => {
        const query = (0, graphql_1.parse)(`
      query Primary {
        union {
          ...on Item {
            scalar
          }
          ...on SecondItem {
            scalar
          }
          ...on SecondItem {
            scalar
          }
        }
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({ defaultComplexity: 1 }),
            ],
            schema: schema_1.default,
            query,
        });
        (0, chai_1.expect)(complexity).to.equal(3);
    });
    it('should calculate max complexity for nested fragment on union type', () => {
        const query = (0, graphql_1.parse)(`
      query Primary {
        union {
          ...on Union {
            ...on Item {
              complexScalar1: complexScalar
            } 
          }
          ...on SecondItem {
            scalar
          }
          ...on Item {
            complexScalar2: complexScalar
          }
        }
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({ defaultComplexity: 0 }),
            ],
            schema: schema_1.default,
            query,
        });
        (0, chai_1.expect)(complexity).to.equal(40);
    });
    it('should calculate max complexity for nested fragment on union type + named fragment', () => {
        const query = (0, graphql_1.parse)(`
      query Primary {
        union {
          ...F
          ...on SecondItem {
            scalar
          }
          ...on Item {
            complexScalar2: complexScalar
          }
        }
      }
      fragment F on Union {
        ...on Item {
          complexScalar1: complexScalar
        } 
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({ defaultComplexity: 0 }),
            ],
            schema: schema_1.default,
            query,
        });
        (0, chai_1.expect)(complexity).to.equal(40);
    });
    it('should calculate max complexity for multiple interfaces', () => {
        const query = (0, graphql_1.parse)(`
      query Primary {
        interface {
          ...on Query {
            complexScalar
          }
          ...on SecondItem {
            name
            name2: name
          }
        }
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({ defaultComplexity: 1 }),
            ],
            schema: schema_1.default,
            query,
        });
        (0, chai_1.expect)(complexity).to.equal(21);
    });
    it('should calculate max complexity for multiple interfaces with nesting', () => {
        const query = (0, graphql_1.parse)(`
      query Primary {
        interface {
          ...on Query {
            complexScalar
            ...on Query {
              a: complexScalar
            }
          }
          ...on SecondItem {
            name
            name2: name
          }
        }
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({ defaultComplexity: 1 }),
            ],
            schema: schema_1.default,
            query,
        });
        (0, chai_1.expect)(complexity).to.equal(41); // 1 for interface, 20 * 2 for complexScalar
    });
    it('should calculate max complexity for multiple interfaces with nesting + named fragment', () => {
        const query = (0, graphql_1.parse)(`
      query Primary {
        interface {
          ...F
          ...on SecondItem {
            name
            name2: name
          }
        }
      }
      
      fragment F on Query {
        complexScalar
        ...on Query {
          a: complexScalar
        }
      }
    `);
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [
                (0, index_1.fieldExtensionsEstimator)(),
                (0, index_1.simpleEstimator)({ defaultComplexity: 1 }),
            ],
            schema: schema_1.default,
            query,
        });
        (0, chai_1.expect)(complexity).to.equal(41); // 1 for interface, 20 * 2 for complexScalar
    });
    it('should include the current node in the estimator args', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        nonNullItem {
          scalar
          complexScalar
          variableScalar(count: 10)
        }
      }
    `);
        const fieldCountEstimator = ({ node }) => {
            if (node.selectionSet) {
                return 10 * node.selectionSet.selections.length;
            }
            return 0;
        };
        const complexity = (0, QueryComplexity_1.getComplexity)({
            estimators: [fieldCountEstimator],
            schema: schema_1.default,
            query: ast,
        });
        (0, chai_1.expect)(complexity).to.equal(30); // 3 fields on nonNullItem * 10
    });
    it('should handle invalid argument values for multiple query fields', () => {
        const ast = (0, graphql_1.parse)(`
      query {
        requiredArgs(count: x) {
          scalar
          complexScalar
        }
        nonNullItem {
          scalar
          complexScalar
          variableScalar(count: 10)
        }
      }
    `);
        (0, graphql_1.validate)(schema_1.default, ast, [
            ...graphql_1.specifiedRules,
            (0, index_1.createComplexityRule)({
                maximumComplexity: 1000,
                estimators: [
                    (0, index_1.simpleEstimator)({
                        defaultComplexity: 1,
                    }),
                ],
            }),
        ]);
    });
});
//# sourceMappingURL=QueryComplexity-test.js.map